//---------------------------------------------------------------
//
// Name: errno.h
// Title: definition of error numbers
// Author: Mario Boller-Olfert
//
// DESCRIPTION
//     In case of errors the global variable errno is set. If
//     you want to chack after a function call, you should set
//     it to zero before. It allways reflects the last error
//     that occured.
//
// History:
//   1.0|03/05/2002|MBO|First implementaion
//---------------------------------------------------------------
#ifndef ERRNO_H
#define ERRNO_H

#include <inttypes.h>

extern uint8_t errno;

#define E2BIG       1 // arg list too long
#define EACCES      2 // permision denied
#define EAGAIN      3 // Resource temporarily unavailable
#define EBADF       4 // bad file descriptor
#define EBADMSG     5 // bad message
#define EBUSY       6 // device or resource busy
#define ECANCELED   7 // operation canceled
#define ECHILD      8 // no child process
#define EEXIST      9 // file exists
#define EFAULT     10 // bad address
#define EFBIG      11 // file too big
#define EINTR      12 // interrupted function
#define EINVAL     13 // invalid argument
#define EIO        14 // i/o error
#define EISDIR     15 // is a directory
#define EMFILE     16 // too many open files
#define EMSGSIZE   17 // message too large
#define ENFILE     18 // too many open files
#define ENOBUFS    19 // no buffer space available
#define ENODEV     20 // no such device
#define ENOENT     21 // no such file or directory
#define ENOEXEC    22 // executable file format error
#define ENOLCK     23 // no locks available
#define ENOMEM     24 // not enough memory space
#define ENOSPC     25 // no space left on device
#define ENOSYS     26 // function not implemented
#define ENOTDIR    27 // not a directory
#define ENOTEMPTY  28 // directory not empty
#define ENOTTY     29 // inappropriate i/o control operation
#define ENOXIO     30 // no such device or address
#define EOVERFLOW  31 // value too large to be stored in data type
#define EPERM      32 // operation not permitted
#define EPIPE      33 // broken pipe
#define EPROTO     34 // protocol error
#define ERANGE     35 // result too large

#endif
